@@ -193,6 +193,7 @@ int main(int argc, char **argv)
 	    if (event) {
 		switch (event->type) {
 		case GDK_DESTROY:
+		case GDK_DELETE:
 		    gdk_exit(0);
 		    exit(0);
 		    break;
@@ -213,6 +214,7 @@ int main(int argc, char **argv)
 		default:
 		    break;
 		}
+		gdk_event_free(event);
 	    }
 	}
 
